/******************************************************************************************************************
TITLE       -  PIVOTS UPPER

FILE        -  pivots upper.mp4

DESCRIPTION -  displays the upper support & resistance lines, R1,R2,R3, M3,M4,M5 on the Screen, as well as 
               their label.  
               
USAGE       -  refer to Pu.pdf

REVISIONS   -  Written by: CrushD
            -  1.0   14/2/06   Heavily Modified by: Mark A Flexhaug, pipaholic@shaw.ca
            
ISSUES      -  does not work for periods > 15 minutes
******************************************************************************************************************/


#property indicator_chart_window
#property indicator_buffers 7

#property indicator_color1 Gray
#property indicator_color2 Blue
#property indicator_color3 Crimson
#property indicator_color4 Blue
#property indicator_color5 Crimson
#property indicator_color6 Navy
#property indicator_color7 Navy

//---- input parameters\
extern   bool ShowLabels  = true;
extern string StartTime = "06:00";
extern string EndTime = "05:55";
extern bool    RunFast     = true;
double p, s1, s2, s3, r1, r2, r3, m0, m1, m2, m3, m4, m5;
double pivotOpen=0;
double pivotHigh=0;
double pivotLow=0;
double pivotClose=0;
bool pivotStarted=false;
bool pivotCompleted=false;

// buffers
double PivotPoint[];
double M3[];
double R1[];
double M4[];
double R2[];
double M5[];
double R3[];

// Some definitions
int   FontSize = 12;

//+------------------------------------------------------------------+
//| Custom indicator initialization function |
//+------------------------------------------------------------------+
int init()
{
//---- indicators
IndicatorShortName("Pivot");

SetIndexStyle(0, DRAW_LINE,STYLE_DASH,1);
SetIndexBuffer(0, PivotPoint);
SetIndexLabel(0, "Pivot Point");

SetIndexStyle(1, DRAW_LINE, STYLE_DASH, 1);
SetIndexBuffer(1, M3);
SetIndexLabel(1, "M3");

SetIndexStyle(2, DRAW_LINE,STYLE_SOLID,1);
SetIndexBuffer(2, R1);
SetIndexLabel(2, "R1");

SetIndexStyle(3, DRAW_LINE, STYLE_DASH, 1);
SetIndexBuffer(3, M4);
SetIndexLabel(3, "M4");

SetIndexStyle(4,DRAW_LINE,STYLE_SOLID,1);
SetIndexBuffer(4, R2);
SetIndexLabel(4, "R2");

SetIndexStyle(5, DRAW_LINE, STYLE_DASH, 1);
SetIndexBuffer(5, M5);
SetIndexLabel(5, "M5");

SetIndexStyle(6, DRAW_LINE,STYLE_SOLID,1);
SetIndexBuffer(6, R3);
SetIndexLabel(6, "R3");

return(0);
}
//+------------------------------------------------------------------+
//| Custor indicator deinitialization function |
//+------------------------------------------------------------------+
int deinit()
{
      ObjectDelete("R1");
      ObjectDelete("R2");
      ObjectDelete("R3");
      ObjectDelete("M3");
      ObjectDelete("M4");
      ObjectDelete("M5");
return(0);
}
//+------------------------------------------------------------------+
//| Custom indicator iteration function |
//+------------------------------------------------------------------+
int start()
{
   int   extra    = 2500;
   int   vYear    = Year();
   int   vMonth   = Month();
   int   vDay     = Day();
   int   vHour    = Hour();
   int   vMinute  = Minute();
   int   i        = Bars,
         limit;
   datetime vNow  = NULL;
   
   if(RunFast) limit = 10 * 24*(60/Period());
   else        limit = Bars;
//   Alert(Symbol(),i);
   for(i=limit; i>=0; i--)
   {
//      if ((Period() >= 1) || (Period() <= 60)) calcPivots(i);
      calcPivots(i);      
      
//      PivotPoint[i] = p;
      R1[i] = r1;
      R2[i] = r2;
      R3[i] = r3;
      M3[i] = m3;      
      M4[i] = m4;      
      M5[i] = m5;
   }
   if(ShowLabels)
   {   
      ObjectDelete("R1");
      ObjectDelete("R2");
      ObjectDelete("R3");
      ObjectDelete("M3");
      ObjectDelete("M4");
      ObjectDelete("M5");
   
      vNow  = StrToTime((vYear+"."+vMonth+"."+vDay+" "+vHour+":"+(vMinute-Period())));
  
      ObjectCreate("R1", OBJ_TEXT, 0, vNow+extra, r1);
      ObjectSetText("R1", "R1", FontSize, "Arial", Navy);

      ObjectCreate("R2", OBJ_TEXT, 0, vNow+extra, r2);
      ObjectSetText("R2", "R2", FontSize, "Arial", Navy);

      ObjectCreate("R3", OBJ_TEXT, 0, vNow+extra, r3);
      ObjectSetText("R3", "R3", FontSize, "Arial", Navy);

      ObjectCreate("M3", OBJ_TEXT, 0, vNow+extra, m3);
      ObjectSetText("M3", "M3", FontSize, "Arial", Navy);

      ObjectCreate("M4", OBJ_TEXT, 0, vNow+extra, m4);
      ObjectSetText("M4", "M4", FontSize, "Arial", Navy);

      ObjectCreate("M5", OBJ_TEXT, 0, vNow+extra, m5);
      ObjectSetText("M5", "M5", FontSize, "Arial", Navy);  
   }
}

void calcPivots(int curBar)
{
   string barTime;
   
   barTime = TimeToStr(Time[curBar], TIME_MINUTES);
//   Alert(Symbol()," ",barTime);
       
   if (barTime == StartTime)
   {
     pivotOpen    = Open[curBar];
     pivotLow     = Low[curBar];
     pivotHigh    = High[curBar];
     pivotStarted = true;
   }

   if (pivotStarted && barTime==EndTime)
   {   
     pivotClose = Close[curBar];
     pivotCompleted = true; 
   }

   if (pivotStarted && pivotHigh < High[curBar])
   {
      pivotHigh = High[curBar];
   } 

   if (pivotStarted && pivotLow > Low[curBar]) 
   {
      pivotLow = Low[curBar];
   }  

   if (pivotCompleted)
   {
      p = (pivotHigh + pivotLow + pivotClose)/3;
      s1 = (2 * p) - pivotHigh;
      r1 = (2 * p) - pivotLow;
      s2 = p - r1 + s1;
      r2 = p -s1 + r1;
      s3 = pivotLow - (2*(pivotHigh - p));
      r3 = pivotHigh + (2*(p - pivotLow));
      m0 = (s2 + s3)/2;
      m1 = (s1 + s2)/2;
      m2 = (p + s1)/2;
      m3 = (p + r1)/2; 
      m4 = (r1 + r2)/2;
      m5 = (r2 + r3)/2;      
      
      pivotStarted = false;
      pivotCompleted = false; 
   }
}

